@@ -28,17 +28,17 @@ class PhysicMaterial(GltfExtensionMixin, gltf_extension_name="HF_physic_material
     """
     A physic material.
 
-    Properties:
-    dynamic_friction (number) The friction used when already moving. Usually a value from 0 to 1.
-        (Optional, default 0.6)
-    static_friction (number) The friction used when laying still on a surface. Usually a value from 0 to 1.
-        (Optional, default 0.6)
-    bounciness (number) How bouncy a surface is. 0 will not bounce, 1 will bounce without any loss of energy.
-        (Optional, default 0)
-    friction_combine (str) How the friction of two surfaces are combined.
-        (Optional, default "average")
-    bounce_combine (str) How the bounciness of two surfaces are combined.
-        (Optional, default "average")
+    Args:
+        dynamic_friction (`float`, *optional*, defaults to `0.6`):
+            The friction used when already moving. Usually a value from 0 to 1.
+        static_friction (`float`, *optional*, defaults to `0.6`):
+            The friction used when laying still on a surface. Usually a value from 0 to 1.
+        bounciness (`float`, *optional*, defaults to `0.0`):
+            How bouncy a surface is. 0 will not bounce, 1 will bounce without any loss of energy.
+        friction_combine (`str`, *optional*, defaults to `"average"`):
+            How the friction of two surfaces are combined.
+        bounce_combine (`str`, *optional*, defaults to `"average"`):
+            How the bounciness of two surfaces are combined.
     """
 
     __NEW_ID: ClassVar[int] = itertools.count()  # Singleton to count instances of the classes for automatic naming
@@ -65,6 +65,13 @@ class PhysicMaterial(GltfExtensionMixin, gltf_extension_name="HF_physic_material
         return id(self)
 
     def copy(self) -> "PhysicMaterial":
+        """
+        Return a copy of the current object.
+
+        Returns:
+            physic_material (`PhysicMaterial`):
+                The copied object.
+        """
         copy_mat = copy.deepcopy(self)
         class_id = next(self.__class__.__NEW_ID)
         self.name = camelcase_to_snakecase(self.__class__.__name__ + f"_{class_id:02d}")
